## array-flat-polyfill
License: CC0-1.0
Source: https://github.com/jonathantneal/array-flat-polyfill

## clone
License: MIT
Source: https://github.com/pvorb/clone

## d3
License: ISC
Source: https://github.com/d3/d3

## delaunator
License: ISC
Source: https://github.com/mapbox/delaunator

## fast-deep-equal
License: MIT
Source: https://github.com/epoberezkin/fast-deep-equal

## fast-json-stable-stringify
License: MIT
Source: https://github.com/epoberezkin/fast-json-stable-stringify

## internmap
License: ISC
Source: https://github.com/mbostock/internmap

## robust-predicates
License: Unlicense
Source: https://github.com/mourner/robust-predicates

## topojson-client
License: ISC
Source: https://github.com/topojson/topojson-client

## vega-lite
License: BSD-3-Clause
Source: https://github.com/vega/vega-lite

## vega
License: BSD-3-Clause
Source: https://github.com/vega/vega